summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sessions/tab_restore_service.cc
diff options
context:
space:
mode:
authoraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-06 17:03:08 +0000
committeraa@chromium.org <aa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-05-06 17:03:08 +0000
commit98aa0b5c0dd2f6721d7c1bb81fe87812fe5573ee (patch)
tree77dd37111cdb925321816cc66da4110d43a03880 /chrome/browser/sessions/tab_restore_service.cc
parent54903eaa08bde272797e0f2a6befa213dd93b9b6 (diff)
downloadchromium_src-98aa0b5c0dd2f6721d7c1bb81fe87812fe5573ee.zip
chromium_src-98aa0b5c0dd2f6721d7c1bb81fe87812fe5573ee.tar.gz
chromium_src-98aa0b5c0dd2f6721d7c1bb81fe87812fe5573ee.tar.bz2
Rename all occurrences of "app extension" with "extension app" since we were using both and consistency is nice.
Review URL: http://codereview.chromium.org/1924002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@46576 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/sessions/tab_restore_service.cc')
-rw-r--r--chrome/browser/sessions/tab_restore_service.cc32
1 files changed, 16 insertions, 16 deletions
diff --git a/chrome/browser/sessions/tab_restore_service.cc b/chrome/browser/sessions/tab_restore_service.cc
index 4dea440..af243d2 100644
--- a/chrome/browser/sessions/tab_restore_service.cc
+++ b/chrome/browser/sessions/tab_restore_service.cc
@@ -49,7 +49,7 @@ const size_t TabRestoreService::kMaxEntries = 10;
// . When the user closes a tab a command of type
// kCommandSelectedNavigationInTab is written identifying the tab and
// the selected index, then a kCommandPinnedState command if the tab was
// pinned and kCommandSetAppExtensionID if the tab has an app id. This is
// followed by any number of kCommandUpdateTabNavigation commands (1 per
// navigation entry).
// . When the user closes a window a kCommandSelectedNavigationInTab command
@@ -62,7 +62,7 @@ static const SessionCommand::id_type kCommandRestoredEntry = 2;
static const SessionCommand::id_type kCommandWindow = 3;
static const SessionCommand::id_type kCommandSelectedNavigationInTab = 4;
static const SessionCommand::id_type kCommandPinnedState = 5;
-static const SessionCommand::id_type kCommandSetAppExtensionID = 6;
+static const SessionCommand::id_type kCommandSetExtensionAppID = 6;
// Number of entries (not commands) before we clobber the file and write
// everything.
@@ -274,7 +274,7 @@ void TabRestoreService::RestoreEntryById(Browser* browser,
browser->ReplaceRestoredTab(tab->navigations,
tab->current_navigation_index,
tab->from_last_session,
- tab->app_extension_id);
+ tab->extension_app_id);
} else {
// Use the tab's former browser and index, if available.
Browser* tab_browser = NULL;
@@ -297,7 +297,7 @@ void TabRestoreService::RestoreEntryById(Browser* browser,
tab_index = tab_browser->tab_count();
tab_browser->AddRestoredTab(tab->navigations, tab_index,
tab->current_navigation_index,
- tab->app_extension_id, true, tab->pinned,
+ tab->extension_app_id, true, tab->pinned,
tab->from_last_session);
}
} else if (entry->type == WINDOW) {
@@ -309,7 +309,7 @@ void TabRestoreService::RestoreEntryById(Browser* browser,
TabContents* restored_tab =
browser->AddRestoredTab(tab.navigations, browser->tab_count(),
tab.current_navigation_index,
- tab.app_extension_id,
+ tab.extension_app_id,
(static_cast<int>(tab_i) ==
window->selected_tab_index),
tab.pinned, tab.from_last_session);
@@ -414,9 +414,9 @@ void TabRestoreService::PopulateTab(Tab* tab,
if (tab->current_navigation_index == -1 && entry_count > 0)
tab->current_navigation_index = 0;
- Extension* extension = controller->tab_contents()->app_extension();
+ Extension* extension = controller->tab_contents()->extension_app();
if (extension)
- tab->app_extension_id = extension->id();
+ tab->extension_app_id = extension->id();
// Browser may be NULL during unit tests.
if (browser) {
@@ -520,10 +520,10 @@ void TabRestoreService::ScheduleCommandsForTab(const Tab& tab,
ScheduleCommand(command);
}
- if (!tab.app_extension_id.empty()) {
+ if (!tab.extension_app_id.empty()) {
ScheduleCommand(
- CreateSetTabAppExtensionIDCommand(kCommandSetAppExtensionID, tab.id,
- tab.app_extension_id));
+ CreateSetTabExtensionAppIDCommand(kCommandSetExtensionAppID, tab.id,
+ tab.extension_app_id));
}
// Then write the navigations.
@@ -757,18 +757,18 @@ void TabRestoreService::CreateEntriesFromCommands(
break;
}
- case kCommandSetAppExtensionID: {
+ case kCommandSetExtensionAppID: {
if (!current_tab) {
// Should be in a tab when we get this.
return;
}
SessionID::id_type tab_id;
- std::string app_extension_id;
- if (!RestoreSetTabAppExtensionIDCommand(command, &tab_id,
- &app_extension_id)) {
+ std::string extension_app_id;
+ if (!RestoreSetTabExtensionAppIDCommand(command, &tab_id,
+ &extension_app_id)) {
return;
}
- current_tab->app_extension_id.swap(app_extension_id);
+ current_tab->extension_app_id.swap(extension_app_id);
break;
}
@@ -884,7 +884,7 @@ bool TabRestoreService::ConvertSessionWindowToWindow(
tab.navigations.swap(session_window->tabs[i]->navigations);
tab.current_navigation_index =
session_window->tabs[i]->current_navigation_index;
- tab.app_extension_id = session_window->tabs[i]->app_extension_id;
+ tab.extension_app_id = session_window->tabs[i]->extension_app_id;
tab.timestamp = Time();
}
}
@@ -49,7 +49,7 @@ const size_t TabRestoreService::kMaxEntries = 10;
// kCommandSelectedNavigationInTab is written identifying the tab and
// the selected index, then a kCommandPinnedState command if the tab was
-// pinned and kCommandSetAppExtensionID if the tab has an app id. This is
+// pinned and kCommandSetExtensionAppID if the tab has an app id. This is
// followed by any number of kCommandUpdateTabNavigation commands (1 per
// navigation entry).